@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gio, GdkPixbuf, Gdk
+from gi.repository import Gio, GdkPixbuf, Gdk, GLib
 
 from hashlib import md5
 
@@ -18,17 +18,16 @@ from lollypop.art_base import BaseArt
 from lollypop.art_album import AlbumArt
 from lollypop.art_artist import ArtistArt
 from lollypop.art_radio import RadioArt
-from lollypop.objects_album import Album
+from lollypop.art_downloader import DownloaderArt
 from lollypop.logger import Logger
-from lollypop.downloader_art import ArtDownloader
-from lollypop.define import CACHE_PATH, TMP_PATH, STORE_PATH, App, StorageType
-from lollypop.utils import create_dir, emit_signal
-
-from time import sleep
-from shutil import rmtree
+from lollypop.define import CACHE_PATH, ALBUMS_WEB_PATH, ALBUMS_PATH
+from lollypop.define import ARTISTS_PATH, TimeStamp
+from lollypop.define import App
+from lollypop.utils import emit_signal
+from lollypop.utils_file import create_dir, remove_oldest
 
 
-class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, ArtDownloader):
+class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, DownloaderArt):
     """
         Global artwork manager
     """
@@ -41,10 +40,19 @@ class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, ArtDownloader):
         AlbumArt.__init__(self)
         ArtistArt.__init__(self)
         RadioArt.__init__(self)
-        ArtDownloader.__init__(self)
+        DownloaderArt.__init__(self)
+        # Move old store
+        # FIXME: Remove this later
+        store = Gio.File.new_for_path(
+            GLib.get_user_data_dir() + "/lollypop/store")
+        if store.query_exists():
+            new_store = Gio.File.new_for_path(ALBUMS_PATH)
+            if not new_store.query_exists():
+                store.move(new_store, Gio.FileCopyFlags.OVERWRITE, None, None)
         create_dir(CACHE_PATH)
-        create_dir(STORE_PATH)
-        create_dir(TMP_PATH)
+        create_dir(ALBUMS_PATH)
+        create_dir(ALBUMS_WEB_PATH)
+        create_dir(ARTISTS_PATH)
 
     def add_artwork_to_cache(self, name, surface, prefix):
         """
@@ -127,53 +135,17 @@ class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, ArtDownloader):
         f = Gio.File.new_for_path(cache_path_jpg)
         return f.query_exists()
 
-    def clean_old_artwork(self):
+    def clean_artwork(self):
         """
-            Slow silent cleaner: web albums are removed from SQL queries
-            so we may have unwanted artwork on disk
-        """
-        def cleaner():
-            sleep(10)
-            f = Gio.File.new_for_path(STORE_PATH)
-            infos = f.enumerate_children(
-                                    "standard::name",
-                                    Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
-                                    None)
-            # Get all files in store
-            files = []
-            for info in infos:
-                sleep(0.1)
-                f = infos.get_child(info)
-                files.append(f.get_basename())
-            infos.close(None)
-            # Remove wanted files
-            for storage_type in [StorageType.SAVED,
-                                 StorageType.SPOTIFY_NEW_RELEASES,
-                                 StorageType.SPOTIFY_SIMILARS]:
-                for album_id in App().albums.get_for_storage_type(
-                        storage_type):
-                    sleep(0.1)
-                    album = Album(album_id)
-                    filename = self.get_album_cache_name(album) + ".jpg"
-                    if filename in files:
-                        files.remove(filename)
-            # Delete remaining files
-            for filename in files:
-                sleep(1)
-                store_path = STORE_PATH + "/" + filename
-                f = Gio.File.new_for_path(store_path)
-                f.delete()
-
-        App().task_helper.run(cleaner)
-
-    def clean_web(self):
-        """
-            Remove all covers from cache
+            Remove old artwork from disk
         """
         try:
-            rmtree(TMP_PATH)
+            remove_oldest(CACHE_PATH, TimeStamp.ONE_YEAR)
+            remove_oldest(ARTISTS_PATH, TimeStamp.THREE_YEAR)
+            remove_oldest(ALBUMS_PATH, TimeStamp.THREE_YEAR)
+            remove_oldest(ALBUMS_WEB_PATH, TimeStamp.ONE_YEAR)
         except Exception as e:
-            Logger.error("Art::clean_web(): %s", e)
+            Logger.error("Art::clean_artwork(): %s", e)
 
     def clean_rounded(self):
         """
