@@ -12,8 +12,8 @@
 
 from gi.repository import Gtk
 
-from lollypop.define import App, Type, ViewType, MARGIN_SMALL
-from lollypop.utils import emit_signal
+from lollypop.define import App, Type, ViewType, MARGIN_SMALL, StorageType
+from lollypop.utils import emit_signal, get_default_storage_type
 
 
 class ViewsContainer:
@@ -33,7 +33,7 @@ class ViewsContainer:
             @param widget as Gtk.Widget
         """
         from lollypop.view import View
-        view = View()
+        view = View(StorageType.ALL, ViewType.DEFAULT)
         view.show()
         view.add(widget)
         widget.set_vexpand(True)
@@ -69,24 +69,28 @@ class ViewsContainer:
         emit_signal(self, "can-go-back-changed", False)
         App().enable_special_shortcuts(False)
 
-    def show_view(self, item_ids, data=None):
+    def show_view(self, item_ids, data=None, storage_type=None):
         """
             Show view for item id
             @param item_ids as [int]
             @param data as object
+            @param storage_type as StorageType
         """
         view = None
+        if storage_type is None:
+            storage_type = get_default_storage_type()
         hide_selection_list = True
         if item_ids:
             if item_ids[0] in [Type.POPULARS,
                                Type.LOVED,
                                Type.RECENTS,
                                Type.LITTLE,
-                               Type.RANDOMS,
-                               Type.WEB]:
-                view = self._get_view_albums(item_ids, [])
+                               Type.RANDOMS]:
+                view = self._get_view_albums(item_ids, [], storage_type)
+            elif item_ids[0] == Type.WEB:
+                view = self._get_view_albums(item_ids, [], StorageType.SAVED)
             elif item_ids[0] == Type.SUGGESTIONS:
-                view = self._get_view_suggestions()
+                view = self._get_view_suggestions(storage_type)
             elif item_ids[0] == Type.SEARCH:
                 view = self.get_view_search(data)
             elif item_ids[0] == Type.INFO:
@@ -99,17 +103,17 @@ class ViewsContainer:
                 view = self._get_view_lyrics()
             elif item_ids[0] == Type.GENRES:
                 if data is None:
-                    view = self._get_view_genres()
+                    view = self._get_view_genres(storage_type)
                 else:
-                    view = self._get_view_albums([data], [])
+                    view = self._get_view_albums([data], [], storage_type)
             elif item_ids[0] == Type.ALBUM:
                 hide_selection_list = False
-                view = self._get_view_album(data)
+                view = self._get_view_album(data, storage_type)
             elif item_ids[0] == Type.YEARS:
                 if data is None:
-                    view = self._get_view_albums_decades()
+                    view = self._get_view_albums_decades(storage_type)
                 else:
-                    view = self._get_view_albums_years(data)
+                    view = self._get_view_albums_years(data, storage_type)
             elif item_ids[0] == Type.PLAYLISTS:
                 view = self._get_view_playlists(data)
             elif item_ids[0] == Type.RADIOS:
@@ -125,11 +129,11 @@ class ViewsContainer:
                                  Type.SETTINGS_DEVICES]:
                 view = self._get_view_settings(item_ids[0])
             elif item_ids[0] == Type.ALL:
-                view = self._get_view_albums(item_ids, [])
+                view = self._get_view_albums(item_ids, [], storage_type)
             elif item_ids[0] == Type.COMPILATIONS:
-                view = self._get_view_albums(item_ids, [])
+                view = self._get_view_albums(item_ids, [], storage_type)
             elif item_ids[0] == Type.ARTISTS:
-                view = self._get_view_artists([], data)
+                view = self._get_view_artists([], data, storage_type)
         self._sidebar.select_ids(item_ids, False)
         if hide_selection_list:
             self._hide_right_list()
@@ -177,7 +181,8 @@ class ViewsContainer:
                     view = _view
                     break
         if view is None:
-            view = SearchView(ViewType.SEARCH | ViewType.SCROLLED)
+            view_type = ViewType.SCROLLED
+            view = SearchView("", view_type)
             view.show()
         if search:
             view.set_search(search)
@@ -224,102 +229,127 @@ class ViewsContainer:
             Show lyrics for track
             @pram track as Track
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_lyrics import LyricsView
-        view = LyricsView()
+        view = LyricsView(view_type)
         view.populate(App().player.current_track)
         view.show()
         return view
 
-    def _get_view_artists_rounded(self):
+    def _get_view_artists_rounded(self, storage_type):
         """
             Get rounded artists view
-            @return view
+            @param storage_type as StorageType
+            @return RoundedArtistsViewWithBanner
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_artists_rounded import RoundedArtistsViewWithBanner
-        view = RoundedArtistsViewWithBanner()
+        view = RoundedArtistsViewWithBanner(storage_type, view_type)
         self._stack.add(view)
         view.populate()
         view.show()
         return view
 
-    def _get_view_artists(self, genre_ids, artist_ids):
+    def _get_view_artists(self, genre_ids, artist_ids, storage_type):
         """
             Get artists view for genres/artists
             @param genre_ids as [int]
             @param artist_ids as [int]
+            @param storage_type as StorageType
+            @return ArtistViewBox/ArtistViewList
         """
+        view_type = ViewType.SCROLLED
         if App().settings.get_value("show-artist-tracks"):
             from lollypop.view_artist_list import ArtistViewList
-            view = ArtistViewList(genre_ids, artist_ids)
+            view = ArtistViewList(genre_ids, artist_ids,
+                                  storage_type, view_type)
         else:
             from lollypop.view_artist_box import ArtistViewBox
-            view = ArtistViewBox(genre_ids, artist_ids)
+            view = ArtistViewBox(genre_ids, artist_ids,
+                                 storage_type, view_type)
         view.populate()
         view.show()
         return view
 
-    def _get_view_suggestions(self):
+    def _get_view_suggestions(self, storage_type):
         """
             Get home view
+            @param storage_type as StorageType
+            @return SuggestionsView
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_suggestions import SuggestionsView
-        view = SuggestionsView()
+        view = SuggestionsView(storage_type, view_type)
         view.populate()
         view.show()
         return view
 
-    def _get_view_albums_decades(self):
+    def _get_view_albums_decades(self, storage_type):
         """
             Get album view for decades
+            @param storage_type as StorageType
+            @return DecadesBoxView
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_decades_box import DecadesBoxView
-        view = DecadesBoxView()
+        view = DecadesBoxView(storage_type, view_type)
         view.populate()
         view.show()
         return view
 
-    def _get_view_album(self, album):
+    def _get_view_album(self, album, storage_type):
         """
             Show album
             @param album as Album
+            @param storage_type as StorageType
+            @return AlbumView
         """
-        from lollypop.view_album import AlbumView
         view_type = ViewType.TWO_COLUMNS | ViewType.SCROLLED |\
             ViewType.OVERLAY | ViewType.ALBUM
-        view = AlbumView(album, view_type)
+        from lollypop.view_album import AlbumView
+        view = AlbumView(album, storage_type, view_type)
         view.populate()
         return view
 
-    def _get_view_genres(self):
+    def _get_view_genres(self, storage_type):
         """
             Get view for genres
+            @param storage_type as StorageType
+            @return GenresBoxView
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_genres_box import GenresBoxView
-        view = GenresBoxView()
+        view = GenresBoxView(storage_type, view_type)
         view.populate()
         view.show()
         return view
 
-    def _get_view_albums_years(self, years):
+    def _get_view_albums_years(self, years, storage_type):
         """
             Get album view for years
             @param years as [int]
+            @param storage_type as StorageType
+            @return AlbumsForYearsBoxView
         """
-        from lollypop.view_albums_box import AlbumsYearsBoxView
         view_type = ViewType.SCROLLED
-        view = AlbumsYearsBoxView([Type.YEARS], years, view_type)
+        from lollypop.view_albums_box import AlbumsForYearsBoxView
+        view = AlbumsForYearsBoxView([Type.YEARS], years,
+                                     storage_type, view_type)
         view.populate()
         return view
 
-    def _get_view_albums(self, genre_ids, artist_ids):
+    def _get_view_albums(self, genre_ids, artist_ids, storage_type):
         """
             Get albums view for genres/artists
             @param genre_ids as [int]
-            @param is compilation as bool
+            @param artist_ids as [int]
+            @param storage_type as StorageType
+            @return AlbumsForGenresBoxView
         """
-        from lollypop.view_albums_box import AlbumsGenresBoxView
         view_type = ViewType.SCROLLED
-        view = AlbumsGenresBoxView(genre_ids, artist_ids, view_type)
+        from lollypop.view_albums_box import AlbumsForGenresBoxView
+        view = AlbumsForGenresBoxView(genre_ids, artist_ids,
+                                      storage_type, view_type)
         view.populate()
         return view
 
@@ -327,9 +357,10 @@ class ViewsContainer:
         """
             Show albums for device at index
             @param index as int
+            @return AlbumsDeviceBoxView
         """
-        from lollypop.view_albums_box import AlbumsDeviceBoxView
         view_type = ViewType.SCROLLED
+        from lollypop.view_albums_box import AlbumsDeviceBoxView
         view = AlbumsDeviceBoxView(index, view_type)
         view.populate()
         return view
@@ -339,8 +370,9 @@ class ViewsContainer:
             Get radios view
             @return RadiosView
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_radios import RadiosView
-        view = RadiosView()
+        view = RadiosView(view_type)
         view.populate()
         return view
 
@@ -349,8 +381,9 @@ class ViewsContainer:
             Get view for information
             @return InformationView
         """
+        view_type = ViewType.SCROLLED
         from lollypop.view_information import InformationView
-        view = InformationView(True)
+        view = InformationView(view_type, True)
         view.populate()
         view.set_margin_top(MARGIN_SMALL)
         view.set_margin_start(MARGIN_SMALL)
@@ -360,6 +393,7 @@ class ViewsContainer:
         """
             Show settings views
             @param item_id as int
+            @return SettingsView/SettingsChildView
         """
         if item_id == Type.SETTINGS:
             from lollypop.view_settings import SettingsView
@@ -368,7 +402,3 @@ class ViewsContainer:
             from lollypop.view_settings import SettingsChildView
             view = SettingsChildView(item_id, ViewType.SCROLLED)
         return view
-
-############
-# PRIVATE  #
-############
