@@ -15,7 +15,7 @@ import itertools
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import App, Type, StorageType
-from lollypop.utils import get_default_storage_type
+from lollypop.utils import get_default_storage_type, make_subrequest
 from lollypop.utils import format_artist_name, remove_static
 
 
@@ -158,7 +158,7 @@ class ArtistsDatabase:
             @return MusicBrainz artist id as str
         """
         with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT mb_artist_id FROM albums\
+            result = sql.execute("SELECT mb_artist_id FROM artists\
                                   WHERE rowid=?", (artist_id,))
             v = result.fetchone()
             if v is not None:
@@ -181,10 +181,11 @@ class ArtistsDatabase:
             result = sql.execute(request, (artist_id, storage_type))
             return len(list(itertools.chain(*result))) != 0
 
-    def get(self, genre_ids=[]):
+    def get(self, genre_ids, storage_type):
         """
             Get all available artists
             @param genre_ids as [int]
+            @param storage_type as StorageType
             @return [int, str, str]
         """
         genre_ids = remove_static(genre_ids)
@@ -194,7 +195,6 @@ class ArtistsDatabase:
             select = "artists.rowid, artists.name, artists.sortname"
         with SqlCursor(App().db) as sql:
             result = []
-            storage_type = get_default_storage_type()
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
@@ -213,62 +213,22 @@ class ArtistsDatabase:
                            WHERE artists.rowid=album_artists.artist_id\
                            AND albums.rowid=album_artists.album_id\
                            AND albums.storage_type & ?\
-                           AND album_genres.album_id=albums.rowid AND ("
-                for genre_id in genre_ids:
-                    request += "album_genres.genre_id=? OR "
-                request += "1=0) ORDER BY artists.sortname\
+                           AND album_genres.album_id=albums.rowid AND"
+                request += make_subrequest("album_genres.genre_id=?",
+                                           "OR",
+                                           len(genre_ids))
+                request += " ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
                 result = sql.execute(request % select, filters)
             return [(row[0], row[1], row[2]) for row in result]
 
-    def get_performers(self, genre_ids=[]):
-        """
-            Get all available performers
-            @param genre_ids as [int]
-            @return [int, str, str]
-        """
-        genre_ids = remove_static(genre_ids)
-        if App().settings.get_value("show-artist-sort"):
-            select = "artists.rowid, artists.sortname, artists.sortname"
-        else:
-            select = "artists.rowid, artists.name, artists.sortname"
-        with SqlCursor(App().db) as sql:
-            result = []
-            storage_type = get_default_storage_type()
-            if not genre_ids or genre_ids[0] == Type.ALL:
-                # Only artist that really have an album
-                result = sql.execute(
-                    "SELECT DISTINCT %s FROM artists, track_artists, tracks\
-                                  WHERE artists.rowid=track_artists.artist_id\
-                                  AND tracks.rowid=track_artists.track_id\
-                                  AND tracks.storage_type & ?\
-                                  ORDER BY artists.sortname\
-                                  COLLATE NOCASE COLLATE LOCALIZED" % select,
-                    (storage_type,))
-            else:
-                filters = (storage_type,)
-                filters += tuple(genre_ids)
-                request = "SELECT DISTINCT %s\
-                           FROM artists, tracks, track_genres, track_artists\
-                           WHERE artists.rowid=track_artists.artist_id\
-                           AND tracks.rowid=track_artists.track_id\
-                           AND tracks.storage_type & ?\
-                           AND track_genres.track_id=tracks.rowid AND ("
-                for genre_id in genre_ids:
-                    request += "track_genres.genre_id=? OR "
-                request += "1=0) ORDER BY artists.sortname\
-                            COLLATE NOCASE COLLATE LOCALIZED"
-                result = sql.execute(request % select, filters)
-            return [(row[0], row[1], row[2]) for row in result]
-
-    def get_randoms(self, limit):
+    def get_randoms(self, limit, storage_type):
         """
             Return random artists
             @param limit as int
             @return [int, str, str]
         """
         with SqlCursor(App().db) as sql:
-            storage_type = get_default_storage_type()
             request = "SELECT DISTINCT artists.rowid,\
                                        artists.name,\
                                        artists.sortname\
@@ -282,15 +242,15 @@ class ArtistsDatabase:
             result = sql.execute(request, (storage_type, limit))
             return [(row[0], row[1], row[2]) for row in result]
 
-    def get_ids(self, genre_ids=[]):
+    def get_ids(self, genre_ids, storage_type):
         """
             Get all available album artists
             @param genre_ids as [int]
+            @param storage_type as StorageType
             @return artist ids as [int]
         """
         with SqlCursor(App().db) as sql:
             result = []
-            storage_type = get_default_storage_type()
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
@@ -310,10 +270,11 @@ class ArtistsDatabase:
                            WHERE artists.rowid=album_artists.artist_id\
                            AND albums.storage_type & ?\
                            AND albums.rowid=album_artists.album_id\
-                           AND album_genres.album_id=albums.rowid AND ("
-                for genre_id in genre_ids:
-                    request += "album_genres.genre_id=? OR "
-                request += "1=0) ORDER BY artists.sortname\
+                           AND album_genres.album_id=albums.rowid AND"
+                request += make_subrequest("album_genres.genre_id=?",
+                                           "OR",
+                                           len(genre_ids))
+                request += " ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
                 result = sql.execute(request, filters)
             return list(itertools.chain(*result))
@@ -333,7 +294,7 @@ class ArtistsDatabase:
 
     def search(self, searched, storage_type):
         """
-            Search for artists looking like string
+            Search for artists looking like searched
             @param searched as str without accents
             @param storage_type as StorageType
             @return artist ids as [int]
