@@ -40,6 +40,7 @@ class ListenBrainz(GObject.GObject):
         """
         GObject.GObject.__init__(self)
         try:
+            self.__queue_id = None
             self.__queue = load(
                 open(LOLLYPOP_DATA_PATH + "/listenbrainz_queue.bin", "rb"))
         except Exception as e:
@@ -53,18 +54,28 @@ class ListenBrainz(GObject.GObject):
             @param track as Track
             @param time as int
         """
-        if App().settings.get_value("disable-scrobbling") or track.id < 0:
+        if not get_network_available("MUSICBRAINZ") and\
+                get_network_available():
+            return
+        if track.id is None or track.id < 0:
             return
         payload = self.__get_payload(track)
         payload[0]["listened_at"] = time
-        self.__submit("single", payload)
+        if App().settings.get_value("disable-scrobbling") or\
+                not get_network_available("MUSICBRAINZ"):
+            self.__queue.append(("single", payload))
+        else:
+            self.__submit("single", payload)
+            self.__clean_queue()
 
     def playing_now(self, track):
         """
             Submit a playing now notification for a track
             @param track as Track
         """
-        if App().settings.get_value("disable-scrobbling") or track.id < 0:
+        if App().settings.get_value("disable-scrobbling"):
+            return
+        if track.id is None or track.id < 0:
             return
         payload = self.__get_payload(track)
         self.__submit("playing_now", payload)
@@ -99,10 +110,15 @@ class ListenBrainz(GObject.GObject):
         """
             Send tracks in queue
         """
-        if self.__queue:
-            (listen_type, payload) = self.__queue.pop(0)
-            App().task_helper.run(self.__request, listen_type, payload)
-            GLib.timeout_add(1000, self.__clean_queue)
+        def queue():
+            if self.__queue:
+                (listen_type, payload) = self.__queue.pop(0)
+                App().task_helper.run(self.__request, listen_type, payload)
+                return True
+            self.__queue_id = None
+
+        if self.__queue_id is None:
+            self.__queue_id = GLib.timeout_add(1000, queue)
 
     def __submit(self, listen_type, payload):
         """
@@ -110,11 +126,7 @@ class ListenBrainz(GObject.GObject):
             @param listen_type as str
             @param payload as []
         """
-        if get_network_available("MUSICBRAINZ"):
-            self.__clean_queue()
-            App().task_helper.run(self.__request, listen_type, payload)
-        else:
-            self.__queue.append((listen_type, payload))
+        App().task_helper.run(self.__request, listen_type, payload)
 
     def __request(self, listen_type, payload, retry=0):
         """
