@@ -17,27 +17,32 @@ from gettext import gettext as _
 from lollypop.define import ViewType, App, MARGIN_SMALL, Type
 from lollypop.adaptive import AdaptiveView
 from lollypop.helper_signals import SignalsHelper, signals_map
+from lollypop.helper_filtering import FilteringHelper
+from lollypop.logger import Logger
 
 
-class View(AdaptiveView, Gtk.Grid, SignalsHelper):
+class View(Gtk.Grid, AdaptiveView, FilteringHelper, SignalsHelper):
     """
         Generic view
     """
 
     @signals_map
-    def __init__(self, view_type=ViewType.DEFAULT):
+    def __init__(self, storage_type, view_type):
         """
             Init view
+            @param storage_type as StorageType
             @param view_type as ViewType
         """
-        AdaptiveView.__init__(self)
         Gtk.Grid.__init__(self)
-        self._view_type = view_type
+        AdaptiveView.__init__(self)
+        FilteringHelper.__init__(self)
+        self.__storage_type = storage_type
+        self.__view_type = view_type
         self.__scrolled_position = None
         self.__destroyed = False
         self.__banner = None
         self.__placeholder = None
-        self._scrolled_value = 0
+        self.scrolled_value = 0
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_border_width(0)
         self.__new_ids = []
@@ -45,19 +50,16 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
         self._empty_icon_name = "emblem-music-symbolic"
 
         if view_type & ViewType.SCROLLED:
-            self._scrolled = Gtk.ScrolledWindow()
+            self.__scrolled = Gtk.ScrolledWindow.new()
             self.__event_controller = Gtk.EventControllerMotion.new(
-                self._scrolled)
+                self.__scrolled)
             self.__event_controller.set_propagation_phase(
                 Gtk.PropagationPhase.TARGET)
             self.__event_controller.connect("leave", self._on_view_leave)
-            self._scrolled.get_vadjustment().connect("value-changed",
-                                                     self._on_value_changed)
-            self._scrolled.show()
-            self._scrolled.set_property("expand", True)
-            self.__viewport = Gtk.Viewport()
-            self._scrolled.add(self.__viewport)
-            self.__viewport.show()
+            self.__scrolled.get_vadjustment().connect("value-changed",
+                                                      self._on_value_changed)
+            self.__scrolled.show()
+            self.__scrolled.set_property("expand", True)
 
         # Stack for placeholder
         self.__stack = Gtk.Stack.new()
@@ -79,12 +81,12 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             @param widget as Gtk.Widget
         """
         self.__stack.add_named(widget, "main")
-        if self._view_type & ViewType.OVERLAY:
+        if self.view_type & ViewType.OVERLAY:
             self.__overlay = Gtk.Overlay.new()
             self.__overlay.show()
-            if self._view_type & ViewType.SCROLLED:
-                self.__overlay.add(self._scrolled)
-                self.__viewport.add(self.__stack)
+            if self.view_type & ViewType.SCROLLED:
+                self.__overlay.add(self.scrolled)
+                self.__scrolled.add(self.__stack)
             else:
                 self.__overlay.add(self.__stack)
             if banner is not None:
@@ -92,12 +94,12 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
                 self.__banner = banner
                 self.__banner.connect("scroll", self.__on_banner_scroll)
             self.add(self.__overlay)
-        elif self._view_type & ViewType.SCROLLED:
-            self.__viewport.add(self.__stack)
+        elif self.view_type & ViewType.SCROLLED:
+            self.__scrolled.add(self.__stack)
             if banner is not None:
                 self.__banner = banner
                 self.add(self.__banner)
-            self.add(self._scrolled)
+            self.add(self.scrolled)
         else:
             if banner is not None:
                 self.__banner = banner
@@ -134,60 +136,92 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
         else:
             self.__stack.set_visible_child_name("main")
 
-    def should_reveal_header(self, adj):
+    def set_scrolled(self, scrolled):
         """
-            Check if we need to reveal header
-            @param adj as Gtk.Adjustment
-            @param delta as int
-            @return int
+            Add an external scrolled window
+            @param scrolled as Gtk.ScrolledWindow
         """
-        value = adj.get_value()
-        reveal = self._scrolled_value > value
-        self._scrolled_value = value
-        return reveal
-
-    def search_for_child(self, text):
-        """
-            Search and hilight child in current view
-            @param text as str
-        """
-        pass
+        self.__scrolled = scrolled
+        self.__view_type |= ViewType.SCROLLED
 
     def activate_child(self):
         """
-            Activate hilighted child
+            Activated typeahead row
         """
-        pass
-
-    def search_prev(self, text):
-        """
-            Search and hilight prev child
-            @param text as str
-        """
-        pass
-
-    def search_next(self, text):
-        """
-            Search and hilight next child
-            @param text as str
-        """
-        pass
+        try:
+            if App().player.is_party:
+                App().lookup_action("party").change_state(
+                    GLib.Variant("b", False))
+            # Search typeahead chil
+            typeahead_child = None
+            for child in self.filtered:
+                style_context = child.get_style_context()
+                if style_context.has_class("typeahead"):
+                    typeahead_child = child
+                    break
+            App().window.container.type_ahead.entry.set_text("")
+            if typeahead_child is not None:
+                # It's a FlowBox child
+                if hasattr(typeahead_child, "data"):
+                    typeahead_child.activate()
+                # It's a track row
+                else:
+                    track = typeahead_child.track
+                    App().player.add_album(track.album)
+                    App().player.load(track.album.get_track(track.id))
+        except Exception as e:
+            Logger.error("View::activate_child: %s" % e)
 
     def set_populated_scrolled_position(self, position):
         """
             Set scrolled position on populated
             @param position as int
         """
-        if self._view_type & ViewType.SCROLLED:
+        if self.view_type & ViewType.SCROLLED:
             self.__scrolled_position = position
 
+    @property
+    def scrolled(self):
+        """
+            Get scrolled widget
+            @return Gtk.ScrolledWindow
+        """
+        if self.view_type & ViewType.SCROLLED:
+            return self.__scrolled
+        else:
+            return Gtk.ScrolledWindow.new()
+
+    @property
+    def banner(self):
+        """
+            Get view banner
+            @return BannerWidget
+        """
+        return self.__banner
+
+    @property
+    def children(self):
+        """
+            Get view children
+            @return [Gtk.Widget]
+        """
+        return []
+
+    @property
+    def storage_type(self):
+        """
+            Get storage type
+            @return StorageType
+        """
+        return self.__storage_type
+
     @property
     def view_type(self):
         """
             View type less sizing
             @return ViewType
         """
-        return self._view_type & ~(ViewType.ADAPTIVE | ViewType.SMALL)
+        return self.__view_type
 
     @property
     def position(self):
@@ -195,8 +229,8 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             Get scrolled position
             @return float
         """
-        if self._view_type & ViewType.SCROLLED:
-            position = self._scrolled.get_vadjustment().get_value()
+        if self.view_type & ViewType.SCROLLED:
+            position = self.scrolled.get_vadjustment().get_value()
         else:
             position = 0
         return position
@@ -222,41 +256,46 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             @param status as bool
             @return bool
         """
-        view_type = self._view_type
+        view_type = self.view_type
         if self.__placeholder is not None and self.__placeholder.is_visible():
             self.__placeholder.set_adaptive(status)
         if status:
-            self._view_type |= ViewType.ADAPTIVE
+            self.__view_type |= ViewType.ADAPTIVE
+            if self.__banner is not None:
+                self.__banner.add_view_type(ViewType.ADAPTIVE)
         else:
-            self._view_type &= ~ViewType.ADAPTIVE
-        return view_type != self._view_type
+            self.__view_type &= ~ViewType.ADAPTIVE
+            if self.__banner is not None:
+                self.__banner.remove_view_type(ViewType.ADAPTIVE)
+        return view_type != self.view_type
 
     def _on_value_changed(self, adj):
         """
             Update margin if needed
         """
         if self.__banner is not None:
-            reveal = self.should_reveal_header(adj)
+            reveal = self.__should_reveal_header(adj)
             self.__banner.set_reveal_child(reveal)
             if reveal:
                 main_widget = self.__stack.get_child_by_name("main")
                 if main_widget is not None:
                     main_widget.set_margin_top(self.__banner.height +
                                                MARGIN_SMALL)
-                if self._view_type & ViewType.SCROLLED:
-                    self._scrolled.get_vscrollbar().set_margin_top(
+                if self.view_type & ViewType.SCROLLED:
+                    self.scrolled.get_vscrollbar().set_margin_top(
                         self.__banner.height)
-            elif self._view_type & ViewType.SCROLLED:
-                self._scrolled.get_vscrollbar().set_margin_top(0)
+            elif self.view_type & ViewType.SCROLLED:
+                self.scrolled.get_vscrollbar().set_margin_top(0)
 
     def _on_album_updated(self, scanner, album_id, added):
         pass
 
     def _on_map(self, widget):
         """
-            Set sidebar_id
+            Set initial view state
             @param widget as GtK.Widget
         """
+        # Set sidebar id
         if self.sidebar_id is None:
             ids = App().window.container.sidebar.selected_ids
             if ids:
@@ -302,17 +341,29 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
 #######################
 # PRIVATE             #
 #######################
+    def __should_reveal_header(self, adj):
+        """
+            Check if we need to reveal header
+            @param adj as Gtk.Adjustment
+            @param delta as int
+            @return int
+        """
+        value = adj.get_value()
+        reveal = self.scrolled_value > value
+        self.scrolled_value = value
+        return reveal
+
     def __on_banner_height_changed(self, banner, height):
         """
             Update scroll margin
             @param banner as BannerWidget
             @param height as int
         """
-        if self._view_type & ViewType.OVERLAY:
+        if self.view_type & ViewType.OVERLAY:
             main_widget = self.__stack.get_child_by_name("main")
             main_widget.set_margin_top(height + MARGIN_SMALL)
-            if self._view_type & ViewType.SCROLLED:
-                self._scrolled.get_vscrollbar().set_margin_top(height)
+            if self.view_type & ViewType.SCROLLED:
+                self.scrolled.get_vscrollbar().set_margin_top(height)
 
     def __on_banner_scroll(self, banner, x, y):
         """
@@ -325,7 +376,7 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             y = 100
         else:
             y = -100
-        adj = self._scrolled.get_vadjustment()
+        adj = self.scrolled.get_vadjustment()
         new_value = adj.get_value() + y
         lower = adj.get_lower()
         upper = adj.get_upper() - adj.get_page_size()
@@ -341,6 +392,6 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
         if self.__scrolled_position is not None and\
                 allocation.height > self.__scrolled_position:
             stack.disconnect_by_func(self.__on_stack_size_allocated)
-            self._scrolled.get_vadjustment().set_value(
+            self.scrolled.get_vadjustment().set_value(
                 self.__scrolled_position)
             self.__scrolled_position = None
