@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -83,6 +83,9 @@ class LovedWidget(Gtk.Bin):
             loved = Type.NONE
         self.__object.set_loved(loved)
         if isinstance(self.__object, Track):
+            # Clear loved playlist artwork cache
+            name = App().playlists.get_name(Type.LOVED)
+            App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
             # Update state on Last.fm
             if App().lastfm is not None:
                 lastfm_status = True if loved == 1 else False
